@@ -177,7 +177,8 @@ class API(object):
 			except APIError:
 				raise
 			except:
-				raise APIError(code = response.status_code, description = " ".join(response.headers['status'].split()[1:]))
+				description = " ".join(response.headers['status'].split()[1:]) if response.headers['status'] else "Unknown Error"
+				raise APIError(code = response.status_code, description = description)
 		if stream:
 			return response
 		if is_json:
@@ -196,6 +197,7 @@ class API(object):
 		return (self.request_token, self.request_token_secret, token_data.get('oauth_callback_confirmed'))
 	
 	def get_auth_url(self, callback_url = None, token = None):
+		self.set_request_token(None, None)
 		if token is None:
 			token, secret, callback_confirmed = self.get_request_token(callback_url)
 		if callback_url and not callback_confirmed:
@@ -231,6 +233,8 @@ class API(object):
 						value.seek(0)
 					except ValueError:
 						pass
+				elif type(value) in [str, unicode]:
+					value = open(value, 'r')
 				del _params[key]
 				if key == 'media':
 					key = 'media[]'
